@@ -73,17 +73,7 @@ describe 'trove::db' do
 
   end
 
-  context 'on Debian platforms' do
-    let :facts do
-      @default_facts.merge({
-        :osfamily               => 'Debian',
-        :operatingsystem        => 'Debian',
-        :operatingsystemrelease => 'jessie',
-      })
-    end
-
-    it_configures 'trove::db'
-
+  shared_examples_for 'trove::db on Debian platforms' do
     context 'using pymysql driver' do
       let :params do
         { :database_connection     => 'mysql+pymysql://trove:trove@localhost/trove', }
@@ -99,16 +89,7 @@ describe 'trove::db' do
     end
   end
 
-  context 'on Redhat platforms' do
-    let :facts do
-      @default_facts.merge({
-        :osfamily               => 'RedHat',
-        :operatingsystemrelease => '7.1',
-      })
-    end
-
-    it_configures 'trove::db'
-
+  shared_examples_for 'trove::db on RedHat platforms' do
     context 'using pymysql driver' do
       let :params do
         { :database_connection     => 'mysql+pymysql://trove:trove@localhost/trove', }
@@ -118,4 +99,17 @@ describe 'trove::db' do
     end
   end
 
+  on_supported_os({
+    :supported_os   => OSDefaults.get_supported_os
+  }).each do |os,facts|
+    context "on #{os}" do
+      let (:facts) do
+        facts.merge!(OSDefaults.get_facts())
+      end
+
+      it_configures 'trove::db'
+      it_configures "trove::db on #{facts[:osfamily]} platforms"
+    end
+  end
+
 end
